@@ -44,7 +44,7 @@ class IngestClient(NamespacedClient):
           <p>Delete one or more IP geolocation database configurations.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-geoip-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-delete-geoip-database>`_
 
         :param id: A comma-separated list of geoip database configurations to delete
         :param master_timeout: The period to wait for a connection to the master node.
@@ -98,7 +98,7 @@ class IngestClient(NamespacedClient):
           <p>Delete IP geolocation database configurations.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-ip-location-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-delete-ip-location-database>`_
 
         :param id: A comma-separated list of IP location database configurations.
         :param master_timeout: The period to wait for a connection to the master node.
@@ -151,11 +151,11 @@ class IngestClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Delete pipelines.
-          Delete one or more ingest pipelines.</p>
+          <p>Delete pipelines.</p>
+          <p>Delete one or more ingest pipelines.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-delete-pipeline>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-delete-pipeline>`_
 
         :param id: Pipeline ID or wildcard expression of pipeline IDs used to limit the
             request. To delete all ingest pipelines in a cluster, use a value of `*`.
@@ -204,8 +204,8 @@ class IngestClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Get GeoIP statistics.
-          Get download statistics for GeoIP2 databases that are used with the GeoIP processor.</p>
+          <p>Get GeoIP statistics.</p>
+          <p>Get download statistics for GeoIP2 databases that are used with the GeoIP processor.</p>
 
 
         `<https://www.elastic.co/docs/reference/enrich-processor/geoip-processor>`_
@@ -248,7 +248,7 @@ class IngestClient(NamespacedClient):
           <p>Get information about one or more IP geolocation database configurations.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-geoip-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-get-geoip-database>`_
 
         :param id: A comma-separated list of database configuration IDs to retrieve.
             Wildcard (`*`) expressions are supported. To get all database configurations,
@@ -296,7 +296,7 @@ class IngestClient(NamespacedClient):
           <p>Get IP geolocation database configurations.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-ip-location-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-get-ip-location-database>`_
 
         :param id: Comma-separated list of database configuration IDs to retrieve. Wildcard
             (`*`) expressions are supported. To get all database configurations, omit
@@ -348,14 +348,14 @@ class IngestClient(NamespacedClient):
           This API returns a local reference of the pipeline.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-get-pipeline>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-get-pipeline>`_
 
         :param id: Comma-separated list of pipeline IDs to retrieve. Wildcard (`*`) expressions
             are supported. To get all ingest pipelines, omit this parameter or use `*`.
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
-        :param summary: Return pipelines without their definitions (default: false)
+        :param summary: Return pipelines without their definitions
         """
         __path_parts: t.Dict[str, str]
         if id not in SKIP_IN_PATH:
@@ -399,8 +399,8 @@ class IngestClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Run a grok processor.
-          Extract structured fields out of a single text field within a document.
+          <p>Run a grok processor.</p>
+          <p>Extract structured fields out of a single text field within a document.
           You must choose which field to extract matched fields from, as well as the grok pattern you expect will match.
           A grok pattern is like a regular expression that supports aliased expressions that can be reused.</p>
 
@@ -452,7 +452,7 @@ class IngestClient(NamespacedClient):
           <p>Refer to the create or update IP geolocation database configuration API.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-put-geoip-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-put-geoip-database>`_
 
         :param id: ID of the database configuration to create or update.
         :param maxmind: The configuration necessary to identify which IP geolocation
@@ -527,7 +527,7 @@ class IngestClient(NamespacedClient):
           <p>Create or update an IP geolocation database configuration.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-put-ip-location-database>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-put-ip-location-database>`_
 
         :param id: The database configuration identifier.
         :param configuration:
@@ -580,6 +580,7 @@ class IngestClient(NamespacedClient):
         body_fields=(
             "deprecated",
             "description",
+            "field_access_pattern",
             "meta",
             "on_failure",
             "processors",
@@ -594,6 +595,9 @@ class IngestClient(NamespacedClient):
         deprecated: t.Optional[bool] = None,
         description: t.Optional[str] = None,
         error_trace: t.Optional[bool] = None,
+        field_access_pattern: t.Optional[
+            t.Union[str, t.Literal["classic", "flexible"]]
+        ] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         if_version: t.Optional[int] = None,
@@ -609,8 +613,8 @@ class IngestClient(NamespacedClient):
         """
         .. raw:: html
 
-          <p>Create or update a pipeline.
-          Changes made using this API take effect immediately.</p>
+          <p>Create or update a pipeline.</p>
+          <p>Changes made using this API take effect immediately.</p>
 
 
         `<https://www.elastic.co/docs/manage-data/ingest/transform-enrich/ingest-pipelines>`_
@@ -621,6 +625,8 @@ class IngestClient(NamespacedClient):
             or updating a non-deprecated index template, Elasticsearch will emit a deprecation
             warning.
         :param description: Description of the ingest pipeline.
+        :param field_access_pattern: Controls how processors in this pipeline should
+            read and write data on a document's source.
         :param if_version: Required version for optimistic concurrency control for pipeline
             updates
         :param master_timeout: Period to wait for a connection to the master node. If
@@ -667,6 +673,8 @@ class IngestClient(NamespacedClient):
                 __body["deprecated"] = deprecated
             if description is not None:
                 __body["description"] = description
+            if field_access_pattern is not None:
+                __body["field_access_pattern"] = field_access_pattern
             if meta is not None:
                 __body["_meta"] = meta
             if on_failure is not None:
@@ -710,7 +718,7 @@ class IngestClient(NamespacedClient):
           You can either specify an existing pipeline to use with the provided documents or supply a pipeline definition in the body of the request.</p>
 
 
-        `<https://www.elastic.co/docs/api/doc/elasticsearch/v9/operation/operation-ingest-simulate>`_
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-ingest-simulate>`_
 
         :param docs: Sample documents to test in the pipeline.
         :param id: The pipeline to test. If you don't specify a `pipeline` in the request
